pub trait CertificateValue: Clone {
const KIND: CertificateKind;
// Required methods
fn chain_id(&self) -> ChainId;
fn epoch(&self) -> Epoch;
fn height(&self) -> BlockHeight;
fn required_blob_ids(&self) -> BTreeSet<BlobId>;
fn hash(&self) -> CryptoHash;
}Expand description
A value that can be certified by a quorum of validators.
Required Associated Constants
Sourceconst KIND: CertificateKind
const KIND: CertificateKind
The kind of certificate this value produces.
Required Methods
Sourcefn height(&self) -> BlockHeight
fn height(&self) -> BlockHeight
Returns the block height this value applies to.
Sourcefn required_blob_ids(&self) -> BTreeSet<BlobId>
fn required_blob_ids(&self) -> BTreeSet<BlobId>
Returns the IDs of all blobs required to validate this value.
Sourcefn hash(&self) -> CryptoHash
fn hash(&self) -> CryptoHash
Returns the hash that uniquely identifies this value.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.